#
# spec file for package gn
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

Name:           gn
Version:        0.20210811
Release:        4.3
Summary:        A meta-build system that generates build files for Ninja
License:        BSD-3-Clause
URL:            https://gn.googlesource.com/
Source0:        %{name}-%{version}.tar.xz
Patch0:         deprecated_copy.patch
ExcludeArch:    ppc
%if %{?suse_version} < 1550
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  ninja
BuildRequires:  python3-base

%description
GN is a meta-build system that generates build files for Ninja.

%prep
%autosetup -p1

%build
ARCH_FLAGS="`echo %{optflags} | sed -e 's/-O2//g'`"
%if 0%{?suse_version} < 1550
export CXX=g++-12
%else
export CXX=g++
%endif
export AR=ar
export CXXFLAGS="${ARCH_FLAGS}"
# bootstrap
python3 build/gen.py \
  --no-strip \
  --no-last-commit-position \
  --no-static-libstdc++
PV=%{version}
cat >out/last_commit_position.h <<-EOF
	#ifndef OUT_LAST_COMMIT_POSITION_H_
	#define OUT_LAST_COMMIT_POSITION_H_
	#define LAST_COMMIT_POSITION_NUM ${PV##0.}
	#define LAST_COMMIT_POSITION "${PV}"
	#endif  // OUT_LAST_COMMIT_POSITION_H_
EOF
%ninja_build -C out gn

%check
%ninja_build -C out gn_unittests
./out/gn_unittests

%install
install -Dm 0755 out/%{name} %{buildroot}%{_bindir}/%{name}

%files
%license LICENSE
%{_bindir}/%{name}

%changelog
* Thu Mar  9 2023 Callum Farmer <gmbr3@opensuse.org>
- Bump Leap's GCC version to 12 to align with the other Chromium
  tools
- Exclude ppc - it doesn't build
* Sun Dec  5 2021 Callum Farmer <gmbr3@opensuse.org>
- Add deprecated_copy.patch: fix deprecated copy GCC warnings
- Go back to GCC
- Use newer libs and GCC on Leap 15.3 & 15.4
* Fri Sep 10 2021 Callum Farmer <gmbr3@opensuse.org>
- Fix build with riscv64
* Wed Sep  1 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 0.20210811:
  * C++ modernization improvements.
  * Minor style updates.
  * Enable GN to build & run on z/OS
  * Fix a typo in the doc of "generated_file"
  * Update doc/help to say --ninja-executable works for VS Flags
  * [rust] Fix and test dylib support
  * Add 'rustenv' to 'gn desc' output
  * [rust] Clean up logic in PullDependentTargetLibsFrom
  * Link Rust binaries against transitive public_deps
  * Fix linking dynamic libraries in Rust binaries
- Remove patches:
  * gn-flags.patch
  * gn-always-python3.patch
  * riscv.patch
* Sat Oct 31 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add riscv.patch to add support for RISCV
* Sat Oct 10 2020 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 0.1807:
  * no upstream changelog
* Thu Apr  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.1726:
  * no upstream changelog
- Rebase patches:
  * gn-always-python3.patch
  * gn-flags.patch
* Wed Oct 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.1616:
  * no upstream changelog
- Remove merged patch gn-add_missing_arm_files.patch
- Add patch to always use python3 in tests:
  * gn-always-python3.patch
* Tue May  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.1544:
  * No upstream changelog
- Rebase patch gn-flags.patch
* Fri Nov  9 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to add missing files to fix armv7 build:
  * gn-add_missing_arm_files.patch
* Tue Oct 30 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 0.1479:
  * No upstream changelog
- Rebase patch gn-flags.patch
* Tue Aug 28 2018 tchvatal@suse.com
- Update to 0.1463:
  * No upstream changelog
- Rebase patch gn-flags.patch
* Mon Aug  6 2018 tchvatal@suse.com
- Fix building on openSUSE Leap 42.3
* Wed Jul 25 2018 tchvatal@suse.com
- Initial commit, package used to generate ninja files, used
  when configuring chromium
